#!/usr/bin/env python2.5

import pexpect
import time
from subprocess import *
import sys

number = sys.argv[1]
message = sys.argv[2]

child = pexpect.spawn('pnatd');
child.send('at\r');
time.sleep(0.25);
child.send('at+cmgf=1\r');
time.sleep(0.25);
child.send('at+cmgs="' + number + '"\r');
child.send(message);
child.send(chr(26));
child.send(chr(26));
child.sendeof();
